@@ -15,14 +15,14 @@ Net::SNTP::Client - Perl module to calculate the roundtrip delay d and
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 
 =cut
 
 ## Version of the Net::SNTP::Client module
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 $VERSION = eval $VERSION;
 
 
@@ -156,7 +156,7 @@ sub getSNTPTime {
 
     return ($error = "Not defined key(s)", \%moduleInput)
 	if (_checkHashKeys(%moduleInput));
-    return ($error = "Not defined Hostname", \%moduleInput)
+    return ($error = "Not defined Hostname/IP", \%moduleInput)
 	if (!$moduleInput{-hostname});
     return ($error = "Not correct port number", \%moduleInput)
 	if (_verifyPort($moduleInput{-port}));
@@ -642,7 +642,7 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =head1 CHANGE LOG
 $Log: Client.pm,v $
-Revision 18.0  2015/09/16 6:27:21 pm  Thanos
+Revision 19.0  2015/09/29 7:17:21 pm  Thanos
 
 =cut
 
